@@ -42,13 +42,13 @@ G_BEGIN_DECLS
 #define LIBBRASERO_MEDIA_VERSION_MAJOR						\
 	3
 #define LIBBRASERO_MEDIA_VERSION_MINOR						\
-	11
+	12
 #define LIBBRASERO_MEDIA_VERSION_MICRO						\
-	4
+	0
 #define LIBBRASERO_MEDIA_AGE							\
 	362
 #define LIBBRASERO_MEDIA_INSTALL							\
-	"/home/mclasen/gnome"
+	"/usr/local"
 
 /**
  * To start and stop the library
